from spotlight.api.rule.data_rule_result.asynchronous import (
    async_get_data_rule_result,
    async_get_data_rule_results,
)
from spotlight.api.rule.data_rule_result.synchronous import (
    get_data_rule_result,
    get_data_rule_results,
)
